# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

from colcon_core.logging import colcon_logger

logger = colcon_logger.getChild(__name__)
